#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mname pyqt-builder
%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-%{mname}
Version:        1.12.2
Release:        150400.1.8
Summary:        The PEP 517 compliant PyQt build system
License:        GPL-2.0-only OR GPL-3.0-only OR SUSE-SIP
URL:            https://www.riverbankcomputing.com/software/pyqt-builder
Source0:        https://files.pythonhosted.org/packages/source/P/PyQt-builder/PyQt-builder-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-sip-devel >= 6.3
Requires:       python-packaging
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-PyQt-builder = %{version}-%{release}
BuildArch:      noarch
# SECTION Test Requirements
BuildRequires:  %{python_module sip-devel >= 6.3}
BuildRequires:  %{python_module packaging}
# /SECTION
%python_subpackages

%description
PyQt-builder is the PEP 517 compliant build system for PyQt and projects that
extend PyQt. It extends the sip build system and uses Qt’s qmake to perform the
actual compilation and installation of extension modules.

Projects that use PyQt-builder provide an appropriate pyproject.toml file and an
optional project.py script. Any PEP 517 compliant frontend, for example
sip-install or pip can then be used to build and install the project.

%prep
%setup -q -n PyQt-builder-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pyqt-bundle
%python_clone -a %{buildroot}%{_bindir}/pyqt-qt-wheel
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1 # boo#1047218
%{python_expand # no real unit tests; check import and bundle entry point
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -c 'import pyqtbuild'
%{buildroot}%{_bindir}/pyqt-bundle-%{$python_bin_suffix} -V
}

%post
%python_install_alternative pyqt-bundle pyqt-qt-wheel

%postun
%python_uninstall_alternative pyqt-bundle

%files %python_files
%license LICENSE*
%doc README NEWS ChangeLog
%python_alternative %{_bindir}/pyqt-bundle
%python_alternative %{_bindir}/pyqt-qt-wheel
%{python_sitelib}/pyqtbuild
%{python_sitelib}/PyQt_builder-%{version}*-info

%changelog
* Fri Oct 29 2021 code@bnavigator.de
- Update to version 1.12.2
  * Bug fix release related to Apple Silicon and Arm64 Qt wheels
* Sat Oct 16 2021 code@bnavigator.de
- Update to version 1.12.1
  * Build universal2 wheels for Qt v6.2 and later when using
    Python v3.10 and later.
  * Added the '--arch' command line option to pyqt-bundle to
    specify a particular architecture (x86_64 or arm64) to
    bundle on macOS.
* Sun Oct  3 2021 code@bnavigator.de
- Update to version 1.11.0
  * Added support for bundling Qt v6.2.
  * Added support for PyQt6-WebEngine to pyqt-bundle.
* Thu Aug 19 2021 code@bnavigator.de
- Don't write mtime-based init pyc file during import test
  (boo#1047218)
* Sun Jul  4 2021 code@bnavigator.de
- Update to version 1.10.3
  * minor bug fixes for Qt v6.1.2
* Tue Jun 15 2021 code@bnavigator.de
- Update to version 1.10.1
  * The default sip module ABI version is now the minimum required
    by current PyQt versions rather than the latest available from
    SIP.
* Thu May 13 2021 code@bnavigator.de
- Update to version 1.10.0
  * Added support for bundling Qt v6.1.
  * Added support for PyQt6-Charts to pyqt-bundle.
  * Added support for PyQt6-DataVisualization to pyqt-bundle.
* Thu Mar 11 2021 code@bnavigator.de
- Update to version 1.9.1
  * Handle the changed Qt installation directory used by PyQt5
    v5.15.4 and later, and PyQt6 v6.0.3 and later.
* Thu Feb 25 2021 code@bnavigator.de
- Update to version 1.9.0
  * Added support for PyQtNetworkAuth.
  * Added support for creating Qt5 wheels.
  * The default minimum glibc version for Qt6 is now v2.28.
* Fri Feb 19 2021 code@bnavigator.de
- Update to version 1.8.0
  * Added the (as yet undocumented) pyqt-qt-wheel utility.
  * chrpath and install_name_tool are no longer required when
    bundling Qt v5.15 or later.
- Changes in v1.7.0
  * Added support for PyQt6, PyQt6-3D and PyQt6-NetworkAuth to
    pyqt-bundle.
* Tue Nov 24 2020 code@bnavigator.de
- Update to version 1.6.0
  * Appropriate defaults are now provided for the 'abi-version' and
    'sip-module' options.
  * Added the 'jobs' builder option and corresponding '--jobs'
    command line option to sip-build, sip-install and sip-wheel.
- Update License tag
* Sun Aug 30 2020 code@bnavigator.de
- Update to version 1.5.0
  * Added the 'android-abis' project option and corresponding
    '--android-abi' command line option to sip-build, sip-install
    and sip-wheel.
  * Added 'PYQTBUILD_VERSION' and 'PYQTBUILD_VERSION_STR' to the
    'pyqtbuild' module API.
  * Added support for bundling QtTextToSpeech.
* Sat Aug 29 2020 code@bnavigator.de
- Specify noarch
- Provide python-PyQt-builder in case packagers search for the
  official Qt/PyPI name
- It actually needs the python-sip-devel package
* Sat Aug 29 2020 code@bnavigator.de
- Initial specfile version 1.4.0
